Macro tls_api::spi_async_socket_impl_delegate [−][src]
Delegate AsyncSocket implementation to the underlying socket.
This is meant to be used only by API implementations.
Delegate AsyncSocket implementation to the underlying socket.
This is meant to be used only by API implementations.