Module tls_api::runtime [−][src]
Tokio or async-std type reexports.
Note rustdoc will likely show tokio types here (because tokio is default), but for async-std, async-std types are imported here.
Structs
| ReadBuf | A wrapper around a byte buffer that is incrementally filled and initialized. |
Traits
| AsyncRead | Reads bytes from a source. |
| AsyncReadExt | Reads bytes from a source. |
| AsyncWrite | Writes bytes asynchronously. |
| AsyncWriteExt | Writes bytes to a sink. |