Struct tls_api::TlsAcceptorBuilderBox [−][src]
Dynamic version of TlsAcceptorBuilder.
Implementations
impl TlsAcceptorBuilderBox[src]
pub fn type_dyn(&self) -> &'static dyn TlsAcceptorType[src]
Dynamic (without type parameter) version of the acceptor.
This function returns an acceptor type, which can be used to constructor acceptors.
pub fn set_alpn_protocols(&mut self, protocols: &[&[u8]]) -> Result<()>[src]
Specify ALPN protocols for negotiation.
This operation returns an error if the implemenation does not support ALPN.
Whether ALPN is supported, can be queried using TlsAcceptor::SUPPORTS_ALPN.
pub fn build(self) -> Result<TlsAcceptorBox>[src]
Finish the acceptor construction.